"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const command_line_args_1 = __importDefault(require("command-line-args"));
const command_line_usage_1 = __importDefault(require("command-line-usage"));
const Logger_1 = __importDefault(require("../Logger"));
const OnPremise_1 = require("../lib/OnPremise");
const AutomateSymbolicationCommand_1 = __importDefault(require("../commands/AutomateSymbolicationCommand"));
const InstallCommand_1 = __importDefault(require("../commands/InstallCommand"));
const ConfigureCommand_1 = __importDefault(require("../commands/ConfigureCommand"));
const InsertCommand_1 = __importDefault(require("../commands/InsertCommand"));
const RepoStatePreCommand_1 = __importDefault(require("../commands/RepoStatePreCommand"));
const OnPremiseUrlsCommand_1 = __importDefault(require("../commands/OnPremiseUrlsCommand"));
const topLevelDefs = [
    {
        name: 'command',
        defaultOption: true
    },
    {
        name: 'help',
        alias: 'h',
        type: Boolean,
        description: 'show this message'
    },
    {
        name: 'version',
        type: Boolean,
        description: 'output the version of the CLI module'
    },
    {
        name: 'project-root',
        type: String,
        description: 'the top level directory of the React Native project. Defaults to the current directory.'
    }
];
function run(argv) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            const opts = (0, command_line_args_1.default)(topLevelDefs, { argv, stopAtFirstUnknown: true });
            if (opts.version) {
                return console.log(`bugsnag-react-native-cli v${require('../../package.json').version}`);
            }
            if (opts.help)
                return usage();
            const projectRoot = opts.projectRoot || process.cwd();
            const remainingOpts = opts._unknown || [];
            switch (opts.command) {
                case 'init': {
                    yield (0, RepoStatePreCommand_1.default)(remainingOpts, projectRoot, opts);
                    const urls = yield (0, OnPremiseUrlsCommand_1.default)(OnPremise_1.UrlType.NOTIFY, OnPremise_1.UrlType.SESSIONS, OnPremise_1.UrlType.UPLOAD, OnPremise_1.UrlType.BUILD);
                    if (!(yield (0, InstallCommand_1.default)(remainingOpts, projectRoot, opts)))
                        return;
                    if (!(yield (0, InsertCommand_1.default)(remainingOpts, projectRoot, opts)))
                        return;
                    if (!(yield (0, ConfigureCommand_1.default)(projectRoot, urls)))
                        return;
                    if (!(yield (0, AutomateSymbolicationCommand_1.default)(projectRoot, urls)))
                        return;
                    Logger_1.default.success('Finished');
                    break;
                }
                case 'insert': {
                    yield (0, RepoStatePreCommand_1.default)(remainingOpts, projectRoot, opts);
                    yield (0, InsertCommand_1.default)(remainingOpts, projectRoot, opts);
                    break;
                }
                case 'configure': {
                    yield (0, RepoStatePreCommand_1.default)(remainingOpts, projectRoot, opts);
                    const urls = yield (0, OnPremiseUrlsCommand_1.default)(OnPremise_1.UrlType.NOTIFY, OnPremise_1.UrlType.SESSIONS);
                    yield (0, ConfigureCommand_1.default)(projectRoot, urls);
                    break;
                }
                case 'install': {
                    yield (0, RepoStatePreCommand_1.default)(remainingOpts, projectRoot, opts);
                    yield (0, InstallCommand_1.default)(remainingOpts, projectRoot, opts);
                    break;
                }
                case 'automate-symbolication': {
                    yield (0, RepoStatePreCommand_1.default)(remainingOpts, projectRoot, opts);
                    const urls = yield (0, OnPremiseUrlsCommand_1.default)(OnPremise_1.UrlType.UPLOAD, OnPremise_1.UrlType.BUILD);
                    yield (0, AutomateSymbolicationCommand_1.default)(projectRoot, urls);
                    break;
                }
                default: {
                    if (opts.command) {
                        Logger_1.default.error(`Unrecognized command "${opts.command}".`);
                    }
                    else {
                        Logger_1.default.error('Command expected, nothing provided.');
                    }
                    usage();
                }
            }
        }
        catch (e) {
            Logger_1.default.error(`Invalid options. ${e.message}`);
            process.exitCode = 1;
        }
    });
}
exports.default = run;
function usage() {
    console.log((0, command_line_usage_1.default)([
        { content: 'bugsnag-react-native-cli <command>' },
        { header: 'Available commands', content: commandList },
        { header: 'Options', optionList: topLevelDefs, hide: ['command'] }
    ]));
}
const commandList = [
    {
        name: 'init',
        summary: 'integrates Bugsnag with a React Native project (this command runs all of the other commands)'
    },
    {
        name: 'install',
        summary: 'installs @bugsnag/react-native'
    },
    {
        name: 'insert',
        summary: 'inserts Bugsnag initialisation into the JS, Android and iOS parts of the codebase'
    },
    {
        name: 'configure',
        summary: 'prompts for necessary configuration and outputs them to the relevant manifests'
    },
    {
        name: 'automate-symbolication',
        summary: 'configures the Xcode and Gradle builds to automatically upload source maps, dsyms and mappings to Bugsnag'
    }
];
//# sourceMappingURL=cli.js.map