"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const prompts_1 = __importDefault(require("prompts"));
const Logger_1 = __importDefault(require("../Logger"));
const Npm_1 = require("../lib/Npm");
const Pod_1 = require("../lib/Pod");
const OnCancel_1 = __importDefault(require("../lib/OnCancel"));
function run(argv, projectRoot, opts) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            yield installJavaScriptPackage(projectRoot);
            Logger_1.default.info('Installing CocoaPods');
            yield (0, Pod_1.install)(projectRoot, Logger_1.default);
            return true;
        }
        catch (e) {
            Logger_1.default.error(e);
            return false;
        }
    });
}
exports.default = run;
function installJavaScriptPackage(projectRoot) {
    return __awaiter(this, void 0, void 0, function* () {
        const alreadyInstalled = yield (0, Npm_1.detectInstalled)('@bugsnag/react-native', projectRoot);
        if (alreadyInstalled) {
            Logger_1.default.warn('@bugsnag/react-native is already installed, skipping');
            return;
        }
        Logger_1.default.info('Adding @bugsnag/react-native dependency');
        const { version } = yield (0, prompts_1.default)({
            type: 'text',
            name: 'version',
            message: 'If you want the latest version of @bugsnag/react-native hit enter, otherwise type the version you want',
            initial: 'latest'
        }, { onCancel: OnCancel_1.default });
        const packageManager = yield (0, Npm_1.guessPackageManager)(projectRoot);
        yield (0, Npm_1.install)(packageManager, '@bugsnag/react-native', version, false, projectRoot);
    });
}
//# sourceMappingURL=InstallCommand.js.map