"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const prompts_1 = __importDefault(require("prompts"));
const Logger_1 = __importDefault(require("../Logger"));
const Repo_1 = require("../lib/Repo");
const OnCancel_1 = __importDefault(require("../lib/OnCancel"));
function run(argv, projectRoot, opts) {
    return __awaiter(this, void 0, void 0, function* () {
        Logger_1.default.info('Detecting repo state');
        const state = (0, Repo_1.detectState)(projectRoot, Logger_1.default);
        const continueByDefault = state === Repo_1.RepoState.GIT_CLEAN;
        Logger_1.default.warn(messages[state]);
        const { confirm } = yield (0, prompts_1.default)({
            type: 'confirm',
            name: 'confirm',
            message: 'Do you want to continue anyway?',
            initial: continueByDefault
        }, { onCancel: OnCancel_1.default });
        if (!confirm)
            process.exit(0);
    });
}
exports.default = run;
const NONE_MSG = `No repo detected.

This command may make modifications to your project. It is recommended that you commit the
current status of your code to a git repo before continuing.`;
const DIRTY_MSG = `Uncommited changes detected.

This command may make modifications to your project. It is recommended that you commit or
stash your current changes before continuing.

Afterwards you can review the diff of the changes made by this command and commit
them to your project.`;
const CLEAN_MSG = `This command may make modifications to your project. Afterwards you can
review the diff and commit them to your project.`;
const UNKNOWN_MSG = `Unable to detect repo state.

This command may make modifications to your project. It is recommended that you commit the
current status of your code to a git repo before continuing.`;
const messages = {
    [Repo_1.RepoState.NONE]: NONE_MSG,
    [Repo_1.RepoState.GIT_DIRTY]: DIRTY_MSG,
    [Repo_1.RepoState.GIT_CLEAN]: CLEAN_MSG,
    [Repo_1.RepoState.UNKNOWN]: UNKNOWN_MSG
};
//# sourceMappingURL=RepoStatePreCommand.js.map