"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.configure = void 0;
const plist_1 = __importDefault(require("plist"));
const path_1 = __importDefault(require("path"));
const fs_1 = require("fs");
const DOCS_LINK = 'https://docs.bugsnag.com/platforms/react-native/react-native/#ios';
function configure(projectRoot, options, logger) {
    return __awaiter(this, void 0, void 0, function* () {
        const iosDir = path_1.default.join(projectRoot, 'ios');
        let xcodeprojDir;
        try {
            xcodeprojDir = (yield fs_1.promises.readdir(iosDir)).find(p => p.endsWith('.xcodeproj'));
        }
        catch (e) { }
        if (!xcodeprojDir) {
            logger.warn(getUnableToFindProjectMessage(options));
            return;
        }
        const plistPath = path_1.default.join(iosDir, xcodeprojDir.replace(/\.xcodeproj$/, ''), 'Info.plist');
        try {
            const infoPlist = plist_1.default.parse(yield fs_1.promises.readFile(plistPath, 'utf8'));
            const bugsnag = (infoPlist.bugsnag || {});
            let hasChanged = false;
            if (options.apiKey) {
                if (bugsnag.apiKey) {
                    logger.warn('API key is already present, skipping');
                }
                else {
                    bugsnag.apiKey = options.apiKey;
                    hasChanged = true;
                }
            }
            if (options.notifyEndpoint) {
                bugsnag.endpoints = bugsnag.endpoints || {};
                if (bugsnag.endpoints.notify) {
                    logger.warn('Notify endpoint is already present, skipping');
                }
                else {
                    bugsnag.endpoints.notify = options.notifyEndpoint;
                    hasChanged = true;
                }
            }
            if (options.sessionsEndpoint) {
                bugsnag.endpoints = bugsnag.endpoints || {};
                if (bugsnag.endpoints.sessions) {
                    logger.warn('Sessions endpoint is already present, skipping');
                }
                else {
                    bugsnag.endpoints.sessions = options.sessionsEndpoint;
                    hasChanged = true;
                }
            }
            if (!hasChanged) {
                return;
            }
            infoPlist.bugsnag = bugsnag;
            yield fs_1.promises.writeFile(plistPath, `${plist_1.default.build(infoPlist, { indent: '\t', indentSize: 1, offset: -1 })}\n`, 'utf8');
            logger.success('Updated Info.plist');
        }
        catch (e) {
            logger.warn(getNoMatchMessage(options));
        }
    });
}
exports.configure = configure;
const HUMAN_READABLE_PROPERTY_NAMES = {
    apiKey: 'API key',
    notifyEndpoint: 'notify endpoint',
    sessionsEndpoint: 'sessions endpoint'
};
function getUnableToFindProjectMessage(options) {
    return `The Xcode configuration was not in the expected location and so couldn't be updated automatically.

Add your ${humanReadableOptions(options)} to the Info.plist in your project.

See ${DOCS_LINK} for more information`;
}
function getNoMatchMessage(options) {
    return `The project's Info.plist couldn't be updated automatically. The plist file may not be valid XML.

Add your ${humanReadableOptions(options)} to the Info.plist in your project manually.

See ${DOCS_LINK} for more information`;
}
function humanReadableOptions(options) {
    return Object.keys(options)
        .map(key => HUMAN_READABLE_PROPERTY_NAMES[key])
        .join(', ')
        .replace(/,(?=[^,]*$)/, ' and');
}
//# sourceMappingURL=InfoPlist.js.map