"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.guessPackageManager = exports.detectInstalled = exports.detectInstalledVersion = exports.install = void 0;
const child_process_1 = require("child_process");
const fs_1 = require("fs");
const path_1 = require("path");
function install(packageManager, module, version, dev, projectRoot) {
    return __awaiter(this, void 0, void 0, function* () {
        let cmd;
        switch (packageManager) {
            case 'yarn':
                cmd = yarnCommand(module, version, dev);
                break;
            case 'npm':
                cmd = npmCommand(module, version, dev);
                break;
            default:
                throw new Error(`Don’t know what command to use for ${packageManager}`);
        }
        return new Promise((resolve, reject) => {
            const proc = (0, child_process_1.spawn)(cmd[0], cmd[1], { cwd: projectRoot, stdio: 'inherit' });
            proc.on('error', err => reject(err));
            proc.on('close', code => {
                if (code === 0)
                    return resolve();
                reject(new Error(`Command exited with non-zero exit code (${code}) "${cmd[0]} ${cmd[1].join(' ')}"`));
            });
        });
    });
}
exports.install = install;
const yarnCommand = (module, version, dev) => [
    'yarn',
    !dev ? ['add', `${module}@${version}`] : ['add', '--dev', `${module}@${version}`]
];
const npmCommand = (module, version, dev) => [
    'npm',
    !dev ? ['install', '--save', `${module}@${version}`] : ['install', '--save-dev', `${module}@${version}`]
];
function detectInstalledVersion(module, projectRoot) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            const pkg = JSON.parse(yield fs_1.promises.readFile((0, path_1.join)(projectRoot, 'package.json'), 'utf8'));
            if (pkg.dependencies && pkg.dependencies[module]) {
                return pkg.dependencies[module];
            }
            if (pkg.devDependencies && pkg.devDependencies[module]) {
                return pkg.devDependencies[module];
            }
            if (pkg.peerDependencies && pkg.peerDependencies[module]) {
                return pkg.peerDependencies[module];
            }
            return undefined;
        }
        catch (e) {
            throw new Error('Could not load package.json. Is this the project root?');
        }
    });
}
exports.detectInstalledVersion = detectInstalledVersion;
function detectInstalled(module, projectRoot) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            const pkg = JSON.parse(yield fs_1.promises.readFile((0, path_1.join)(projectRoot, 'package.json'), 'utf8'));
            const allDeps = Object.assign(Object.assign(Object.assign({}, pkg.dependencies), pkg.devDependencies), pkg.peerDependencies);
            return !!allDeps[module];
        }
        catch (e) {
            throw new Error('Could not load package.json. Is this the project root?');
        }
    });
}
exports.detectInstalled = detectInstalled;
function guessPackageManager(projectRoot) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            yield fs_1.promises.readFile((0, path_1.join)(projectRoot, 'yarn.lock'));
            return 'yarn';
        }
        catch (e) {
            return 'npm';
        }
    });
}
exports.guessPackageManager = guessPackageManager;
//# sourceMappingURL=Npm.js.map