"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.install = void 0;
const child_process_1 = require("child_process");
const fs_1 = require("fs");
const path_1 = require("path");
const os_1 = require("os");
function install(projectRoot, logger) {
    return __awaiter(this, void 0, void 0, function* () {
        if ((0, os_1.platform)() !== 'darwin') {
            logger.warn('Detected platform is not macOS, skipping');
            return;
        }
        try {
            const iosDirList = yield fs_1.promises.readdir((0, path_1.join)(projectRoot, 'ios'));
            if (!iosDirList.includes('Podfile')) {
                logger.warn('No Podfile found in ios directory, skipping');
                return;
            }
        }
        catch (e) {
            if (e.code === 'ENOENT') {
                logger.warn('No ios directory found in project, skipping');
                return;
            }
            throw e;
        }
        const res = (0, child_process_1.spawnSync)('pod', ['install'], { cwd: (0, path_1.join)(projectRoot, 'ios'), stdio: 'inherit' });
        if (res.error) {
            if (res.error.code === 'ENOENT') {
                logger.warn(COCOAPODS_NOT_FOUND);
                return;
            }
            throw res.error;
        }
        if (res.status !== 0) {
            throw new Error(`Command "pod install" exited with non-zero exit code (${res.status})`);
        }
    });
}
exports.install = install;
const COCOAPODS_NOT_FOUND = `CocoaPods does not appear to be installed.

Install it and run "pod install" inside the "ios" directory manaully.`;
//# sourceMappingURL=Pod.js.map